@@ -1,10 +1,6 @@
-import jax
-import jax.numpy as jnp
 import numpy as np
-from typing import Optional, Union
+from typing import Optional
 from os import path
-import os
-from typing import Dict
 
 import autoarray as aa
 import autofit as af
@@ -137,8 +133,8 @@ class PositionsLH:
             f.write("")
 
     def log_likelihood_penalty_from(
-        self, instance: af.ModelInstance, analysis: AnalysisDataset
-    ) -> jnp.array:
+        self, instance: af.ModelInstance, analysis: AnalysisDataset, xp=np
+    ) -> np.array:
         """
         Returns a log-likelihood penalty used to constrain lens models where multiple image-plane
         positions do not trace to within a threshold distance of one another in the source-plane.
@@ -176,23 +172,31 @@ class PositionsLH:
         tracer = analysis.tracer_via_instance_from(instance=instance)
 
         if not tracer.has(cls=ag.mp.MassProfile) or len(tracer.planes) == 1:
-            return (jnp.array(0.0),)
+            return xp.array(0.0)
 
         positions_fit = SourceMaxSeparation(
             data=self.positions,
             noise_map=None,
             tracer=tracer,
             plane_redshift=self.plane_redshift,
+            xp=xp,
         )
 
-        max_separation = jnp.max(
+        max_separation = xp.max(
             positions_fit.furthest_separations_of_plane_positions.array
         )
 
         penalty = self.log_likelihood_penalty_factor * (max_separation - self.threshold)
 
-        return jax.lax.cond(
-            max_separation > self.threshold,
-            lambda: penalty,
-            lambda: jnp.array(0.0),
-        )
+        if xp.__name__.startswith("jax"):
+
+            import jax
+
+            return jax.lax.cond(
+                max_separation > self.threshold,
+                lambda: penalty,
+                lambda: xp.array(0.0),
+            )
+
+        return penalty if max_separation > self.threshold else np.array(0.0)
+
