@@ -1,3 +1,6 @@
+import numpy as np
+
+
 class MockTracer:
     def __init__(
         self, traced_grid_2d_list_from=None, image_plane_mesh_grid_pg_list=None
@@ -5,7 +8,7 @@ class MockTracer:
         self.image_plane_mesh_grid_pg_list = image_plane_mesh_grid_pg_list
         self._traced_grid_2d_list_from = traced_grid_2d_list_from
 
-    def traced_grid_2d_list_from(self, grid):
+    def traced_grid_2d_list_from(self, grid, xp=np):
         return self._traced_grid_2d_list_from
 
     def plane_index_via_redshift_from(self, redshift):
@@ -52,7 +55,7 @@ class MockTracerPoint(MockTracer):
     def traced_grid_2d_list_from(self, grid, plane_index_limit=None):
         return [self.positions]
 
-    def magnification_2d_via_hessian_from(self, grid, deflections_func=None):
+    def magnification_2d_via_hessian_from(self, grid, deflections_func=None, xp=np):
         return self.magnification
 
     def einstein_radius_from(self, grid):
@@ -61,5 +64,5 @@ class MockTracerPoint(MockTracer):
     def einstein_mass_angular_from(self, grid):
         return self.einstein_mass
 
-    def time_delays_from(self, grid):
+    def time_delays_from(self, grid, xp=np):
         return self.time_delays
