@@ -1,4 +1,3 @@
-import jax.numpy as jnp
 import numpy as np
 
 from autolens.point.fit.positions.image.abstract import AbstractFitPositionsImagePair
@@ -84,7 +83,7 @@ class FitPositionsImagePairAll(AbstractFitPositionsImagePair):
             The log probability of the model coordinate explaining the observed coordinate.
         """
         chi2 = self.square_distance(data_position, model_position) / sigma**2
-        return -jnp.log(jnp.sqrt(2 * jnp.pi * sigma**2)) - 0.5 * chi2
+        return -self._xp.log(self._xp.sqrt(2 * self._xp.pi * sigma**2)) - 0.5 * chi2
 
     def all_permutations_log_likelihoods(self) -> np.ndarray:
         """
@@ -103,13 +102,13 @@ class FitPositionsImagePairAll(AbstractFitPositionsImagePair):
 
         model_data = self.model_data.array
 
-        return jnp.array(
+        return self._xp.array(
             [
-                jnp.log(
-                    jnp.sum(
-                        jnp.array(
+                self._xp.log(
+                    self._xp.sum(
+                        self._xp.array(
                             [
-                                jnp.exp(
+                                self._xp.exp(
                                     self.log_p(
                                         data_position,
                                         model_position,
@@ -143,12 +142,13 @@ class FitPositionsImagePairAll(AbstractFitPositionsImagePair):
 
         This is every way in which the coordinates generated by the model can explain the observed coordinates.
         """
-        n_non_nan_model_positions = jnp.count_nonzero(
-            jnp.isfinite(
+        n_non_nan_model_positions = self._xp.count_nonzero(
+            self._xp.isfinite(
                 self.model_data.array,
             ).any(axis=1)
         )
         n_permutations = n_non_nan_model_positions ** len(self.data)
         return -2.0 * (
-            -jnp.log(n_permutations) + jnp.sum(self.all_permutations_log_likelihoods())
+            -self._xp.log(n_permutations)
+            + self._xp.sum(self.all_permutations_log_likelihoods())
         )
