@@ -31,3 +31,16 @@ class Step:
     neighbourhood: aa.AbstractTriangles
     up_sampled: aa.AbstractTriangles
     plane_triangles: aa.AbstractTriangles
+
+    def tree_flatten(self):
+        return (
+            self.number,
+            self.initial_triangles,
+            self.filtered_triangles,
+            self.neighbourhood,
+            self.up_sampled,
+        ), ()
+
+    @classmethod
+    def tree_unflatten(cls, _, values):
+        return cls(*values)
