@@ -13,6 +13,8 @@ import datetime
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
 
+from pyprojroot import here
+
 import os
 import sys
 
@@ -41,11 +43,11 @@ extensions = [
     "sphinx.ext.intersphinx",
     "sphinx.ext.mathjax",
     "sphinx.ext.todo",
-    "sphinx.ext.napoleon",
     "sphinx.ext.viewcode",
-    "sphinx_autodoc_typehints",  # Automatically document param types (less noise in class signature)
+    "sphinx.ext.napoleon",
     "numpydoc",
-    # External stuff
+    "sphinx_autodoc_typehints",
+    # external
     "myst_parser",
     "sphinx_copybutton",
     "sphinx_design",
@@ -80,7 +82,11 @@ myst_heading_anchors = 3
 autosummary_generate = True
 autosummary_imported_members = True
 autodoc_member_order = "bysource"
-autodoc_default_flags = ["members"]
+autodoc_default_options = {
+    "members": True,
+    "undoc-members": True,
+    "show-inheritance": True,
+}
 autodoc_class_signature = "separated"
 autoclass_content = "init"
 
@@ -91,7 +97,16 @@ nnumpydoc_class_members_toctree = True
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
+exclude_patterns = [
+    "_build",
+    "Thumbs.db",
+    ".DS_Store",
+    "CODE_OF_CONDUCT.md",
+    "CONTRIBUTING.md",
+    "CITATIONS.rst",
+    "README.rst",
+    "README.md",
+]
 
 
 # -- Options for HTML output -------------------------------------------------
@@ -132,3 +147,7 @@ html_theme_options = {
 from sphinx.builders.html import StandaloneHTMLBuilder
 
 StandaloneHTMLBuilder.supported_image_types = ["image/gif", "image/png", "image/jpeg"]
+
+typehints_fully_qualified = False
+always_document_param_types = False
+typehints_document_rtype = False
